@@ -266,7 +266,7 @@ void MainWindow::on_fontprimary_clicked()
 {
     const QString COLOR_STYLE("QPushButton { color : %2; background-color: %3; border: 2px; border-style: solid; border-color: %4; border-radius: 8px; margin: 5px; padding: 5px;}");
 
-    QColor current = ui->font1->text();
+    QColor current = f1;
     QColor color1 = colors.getColor(current.name());
     f1 = color1.name();
 
@@ -281,7 +281,7 @@ void MainWindow::on_fontsecondary_clicked()
 {
     const QString COLOR_STYLE("QPushButton { color : %2; background-color: %3; border: 2px; border-style: solid; border-color: %4; border-radius: 8px; margin: 5px; padding: 5px;}");
 
-    QColor current = ui->font2->text();
+    QColor current = f2;
     QColor color2 = colors.getColor(current.name());
     f2 = color2.name();
 
@@ -295,7 +295,7 @@ void MainWindow::on_fontactive_clicked()
 {
     const QString COLOR_STYLE("QPushButton { color : %2; background-color: %3; border: 2px; border-style: solid; border-color: %4; border-radius: 8px; margin: 5px; padding: 5px;}");
 
-    QColor current = ui->font3->text();
+    QColor current = f3;
     QColor color3 = colors.getColor(current.name());
     f3 = color3.name();
 
@@ -309,7 +309,7 @@ void MainWindow::on_fontdisabled_clicked()
 {
     const QString COLOR_STYLE("QPushButton { color : %2; background-color: %3; border: 2px; border-style: solid; border-color: %4; border-radius: 8px; margin: 5px; padding: 5px;}");
 
-    QColor current = ui->font4->text();
+    QColor current = f4;
     QColor color4 = colors.getColor(current.name());
     f4 = color4.name();
 
@@ -323,7 +323,7 @@ void MainWindow::on_fontpainted_clicked()
 {
     const QString COLOR_STYLE("QPushButton { color : %2; background-color: %3; border: 2px; border-style: solid; border-color: %4; border-radius: 8px; margin: 5px; padding: 5px;}");
 
-    QColor current = ui->font5->text();
+    QColor current = f5;
     QColor color5 = colors.getColor(current.name());
     f5 = color5.name();
 
@@ -337,7 +337,7 @@ void MainWindow::on_fontdisabled_2_clicked()
 {
     const QString COLOR_STYLE("QPushButton { color : %2; background-color: %3; border: 2px; border-style: solid; border-color: %4; border-radius: 8px; margin: 5px; padding: 5px;}");
 
-    QColor current = ui->font6->text();
+    QColor current = f6;
     QColor color6 = colors.getColor(current.name());
     f6 = color6.name();
 
@@ -352,7 +352,7 @@ void MainWindow::on_fontbutton_clicked()
 {
     const QString COLOR_STYLE("QPushButton { color : %2; background-color: %3; border: 2px; border-style: solid; border-color: %4; border-radius: 8px; margin: 5px; padding: 5px;}");
 
-    QColor current = ui->font7->text();
+    QColor current = f7;
     QColor color7 = colors.getColor(current.name());
     f7 = color7.name();
 
@@ -366,7 +366,7 @@ void MainWindow::on_fontbuttonpressed_clicked()
 {
     const QString COLOR_STYLE("QPushButton { color : %2; background-color: %3; border: 2px; border-style: solid; border-color: %4; border-radius: 8px; margin: 5px; padding: 5px;}");
 
-    QColor current = ui->font8->text();
+    QColor current = f8;
     QColor color8 = colors.getColor(current.name());
     f8 = color8.name();
 
